netutil

package
v0.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 31, 2026 License: MIT Imports: 3 Imported by: 0

Documentation

Overview

Package netutil contains protocol-independent network address helpers.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ParseIPv4Pool

func ParseIPv4Pool(value string) (network netip.Prefix, gateway, client netip.Addr, err error)

ParseIPv4Pool parses an IPv4 prefix whose first two host addresses are used as the server gateway and the first client address.

func ParseIPv6Pool

func ParseIPv6Pool(value string) (network netip.Prefix, gateway, client netip.Addr, err error)

ParseIPv6Pool is the IPv6 counterpart of ParseIPv4Pool.

Types

This section is empty.

Jump to