Documentation
¶
Overview ¶
Package netutil contains protocol-independent network address helpers.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ParseIPv4Pool ¶
ParseIPv4Pool parses an IPv4 prefix whose first two host addresses are used as the server gateway and the first client address.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.